@@ -148,7 +148,22 @@ class Agent:
                         if not self.is_manager:
                             if self.verbose:
                                 print(f"✓ [{self.name}] Result: {str_result}")
-                            return str_result
+                            
+                            # Generate natural language response using the tool result
+                            final_response = self.client.chat.completions.create(
+                                model=self.model_name,
+                                messages=[
+                                    {"role": "system", "content": self.system_prompt},
+                                    {"role": "user", "content": input_message},
+                                    {"role": "function", "name": tool.name, "content": str_result},
+                                    {"role": "system", "content": "Use the tool's result to provide a natural, helpful response."}
+                                ]
+                            )
+                            
+                            nl_response = final_response.choices[0].message.content
+                            if self.memory is not None:
+                                self.memory.add_message("assistant", nl_response)
+                            return nl_response
                         
                         tool_results.append({"tool": tool.name, "result": str_result})
             
@@ -161,11 +176,12 @@ class Agent:
                         {"role": "user", "content": results_text}
                     ]
                 )
-                result = final_response.choices[0].message.content
+
+                result = final_response.choices[0].message
                 self.memory.add_message("assistant", result)
                 return result
         
-        return assistant_message.content or "I couldn't generate a response."
+        return assistant_message or "I couldn't generate a response."
 
 class ManagerAgent(Agent):
     """
